@@ -10,13 +10,12 @@ class TransformerForImageDetection(Transformer):
     def __init__(self,technique,dictLabels=None):
         Transformer.__init__(self,technique,dictLabels)
 
-    def transform(self, image, boxes):
+    def transform(self, image, boxes,force=False):
         newImage = self.technique.apply(image)
-
         if (isinstance(self.technique, PositionVariantTechnique)):
             newBoxes = detectBoxes(image.shape[:2], boxes, self.technique)
             newBoxes = [(self.transformLabel(box[0]),box[1],box[2]) for box in newBoxes]
         else:
             newBoxes= [(self.transformLabel(box[0]),box[1],box[2]) if len(box)==3 else (self.transformLabel(box[0]),box[1],1.0) for box in boxes]
-
+        
         return [newImage,newBoxes]
